pub fn get_traffic_flow_parts(
_input: GetTrafficFlowInput,
) -> Result<RequestParts<()>, Error>Expand description
Returns a link to a JSON file containing hourly average traffic flow, taken from a representative month of every quarter during 0700-0900 hours. Update freq: Quarterly